summaryrefslogtreecommitdiffstats
path: root/kmymoney2/kmymoney2.h
diff options
context:
space:
mode:
Diffstat (limited to 'kmymoney2/kmymoney2.h')
-rw-r--r--kmymoney2/kmymoney2.h26
1 files changed, 13 insertions, 13 deletions
diff --git a/kmymoney2/kmymoney2.h b/kmymoney2/kmymoney2.h
index c714ea0..56f1725 100644
--- a/kmymoney2/kmymoney2.h
+++ b/kmymoney2/kmymoney2.h
@@ -93,7 +93,7 @@ namespace KMyMoneyPlugin { class ImporterPlugin; }
*
* @short Main application class.
*/
-class KMyMoney2App : public KMainWindow, public DCOPObject
+class KMyMoney2App : public TDEMainWindow, public DCOPObject
{
Q_OBJECT
//
@@ -505,7 +505,7 @@ public:
const TQValueList<TQCString> instanceList(void) const;
/**
- * Dump a list of the names of all defined KActions to stdout.
+ * Dump a list of the names of all defined TDEActions to stdout.
*/
void dumpActions(void) const;
@@ -580,7 +580,7 @@ protected:
*/
void readOptions(void);
- /** initializes the KActions of the application */
+ /** initializes the TDEActions of the application */
void initActions(void);
/** initializes the dynamic menus (account selectors) */
@@ -1001,7 +1001,7 @@ public slots:
void slotCategoryNew(MyMoneyAccount& account, const MyMoneyAccount& parent = MyMoneyAccount());
/**
* This method updates all KAction items to the current state.
*/
void slotUpdateActions(void);
@@ -1162,24 +1162,24 @@ signals:
public:
/**
* This method retrieves a pointer to a KAction object from actionCollection().
* If the action with the name @p actionName is not found, a pointer to
* a static non-configured KAction object is returned and a warning is
* printed to stderr.
*
* @param actionName name of the action to be retrieved
* @return pointer to KAction object (or derivative)
*/
- KAction* action(const TQString& actionName) const;
+ TDEAction* action(const TQString& actionName) const;
/**
* This method is implemented for convenience. It returns a dynamic_cast-ed
* pointer to an action found in actionCollection().
* If the action with the name @p actionName is not found or the object
* is not of type KToggleAction, a pointer to a static non-configured
* KToggleAction object is returned and a warning is printed to stderr.
*/
- KToggleAction* toggleAction(const TQString& actionName) const;
+ TDEToggleAction* toggleAction(const TQString& actionName) const;
private:
@@ -1252,8 +1252,8 @@ private:
bool m_bCheckSchedules;
- KToolBarPopupAction* m_previousViewButton;
- KToolBarPopupAction* m_nextViewButton;
+ TDEToolBarPopupAction* m_previousViewButton;
+ TDEToolBarPopupAction* m_nextViewButton;
TQObject* m_pluginInterface;
@@ -1001,7 +1001,7 @@ public slots:
void slotCategoryNew(MyMoneyAccount& account, const MyMoneyAccount& parent = MyMoneyAccount());
/**
- * This method updates all KAction items to the current state.
+ * This method updates all TDEAction items to the current state.
*/
void slotUpdateActions(void);
@@ -1162,24 +1162,24 @@ signals:
public:
/**
- * This method retrieves a pointer to a KAction object from actionCollection().
+ * This method retrieves a pointer to a TDEAction object from actionCollection().
* If the action with the name @p actionName is not found, a pointer to
@@ -1162,24 +1162,24 @@ signals:
* If the action with the name @p actionName is not found, a pointer to
- * a static non-configured KAction object is returned and a warning is
+ * a static non-configured TDEAction object is returned and a warning is
* printed to stderr.
*
@@ -1162,24 +1162,24 @@ signals:
*
* @param actionName name of the action to be retrieved
- * @return pointer to KAction object (or derivative)
+ * @return pointer to TDEAction object (or derivative)
*/
@@ -1162,24 +1162,24 @@ signals:
* pointer to an action found in actionCollection().
* If the action with the name @p actionName is not found or the object
- * is not of type KToggleAction, a pointer to a static non-configured
- * KToggleAction object is returned and a warning is printed to stderr.
+ * is not of type TDEToggleAction, a pointer to a static non-configured
+ * TDEToggleAction object is returned and a warning is printed to stderr.
*/